---
title: '[공지] 엑심베이 Molpay 서비스 중단 안내'
category: 공지사항
tags:
  - 엑심베이
  - 공지사항
datetime: 2023-11-29T15:00:00.000Z
---

안녕하세요, 포트원 고객지원팀입니다.

‘엑심베이’ 결제대행사 서비스 중 Molpay 가 11월 24일부로 서비스 중단될 예정이며,자세한 사항은 아래 엑심베이 공지사항을 참고하시어 서비스 운영간 차질이 없으시길 바랍니다.

감사합니다.

---

안녕하세요, Eximbay 입니다.항상 저희 엑심베이 결제 서비스를 이용해 주셔서 감사합니다.

말레이시아 고객 타겟의 간편결제수단인 "Razer Merchant Services(구 Molpay)"가 결제사 정책으로 인해 23.11.24일부로 영구 중단되오니, 각 사업장주 및 실무자 분들은 업무에 참고하여 주시기 바랍니다.

- 중단 결제수단: Razer Merchant Services(구 Molpay)
- 중단 시점: 2023.11.24(금) 14:00 \~

엑심베이 통합결제창을 이용하시는 사업장일 경우, 위 시간부로 엑심베이 결제창에 해당 결제수단이 노출되지 않게 되오니 별도로 작업해 주실 사항은 없습니다.

다만 결제수단을 별도로 호출하고 계신 사업장일 경우, 위 중단 시점 이후로는 해당 결제수단이 노출되지 않도록 사전 작업을 요청 드립니다.

- 중단 시점 이후에는 Razer Merchant Services의 Paymethod("P171")를 호출하지 않도록 작업하여 주시기 바랍니다

---
